@@ -210,6 +210,29 @@ class ReadTest(unittest.TestCase):
         data = list(row_set)
         assert_equal(4000, len(data))
 
+    def test_skip_initials(self):
+        def rows(skip_policy):
+            fh = horror_fobj('skip_initials.csv')
+            table_set = CSVTableSet.from_fileobj(fh,
+                                                 skipinitialspace=skip_policy)
+            row_set = table_set.tables[0]
+            return row_set
+
+        second = lambda r: r[1].value
+
+        print map(second, rows(True))
+
+        assert "goodbye" in map(second, rows(True))
+        assert "    goodbye" in map(second, rows(False))
+
+    def test_bad_first_sheet(self):
+        # First sheet appears to have no cells
+        fh = horror_fobj('problematic_first_sheet.xls')
+        table_set = XLSTableSet.from_fileobj(fh)
+        tables = table_set.tables
+        assert_equal(0, len(list(tables[0].sample)))
+        assert_equal(1000, len(list(tables[1].sample)))
+
 
 class TypeGuessTest(unittest.TestCase):
     def test_type_guess(self):
@@ -232,7 +255,8 @@ class TypeGuessTest(unittest.TestCase):
             1,   2012/2/12, 2,      2,02 October 2011,"100.234354"
             2,   2012/2/12, 1.1,    0,1 May 2011,"100,000,000.12"
             foo, bar,       1500,   0,,"NaN"
-            4,   2012/2/12, 42,"-2,000",24 October 2012,"42"''')
+            4,   2012/2/12, 42,"-2,000",24 October 2012,"42"
+            ,,,,,''')
         rows = CSVTableSet(csv_file).tables[0]
         guessed_types = type_guess(rows.sample, strict=True)
         assert_equal(guessed_types, [StringType(), StringType(), DecimalType(), IntegerType(), DateType('%d %B %Y'), FloatType()])
